pub struct AnalyzerItem { /* private fields */ }Expand description
An instantiation of FancyInput::Item used by CircuitAnalyzer.
A dummy FancyItem which is returned when profiling a Fancy circuit.
The AnalyzerItem contains the wire modulus and the depth of the computation.
This is because Fancy::Item needs to implement HasModulus.