CircuitAnalyzer

Struct CircuitAnalyzer 

pub struct CircuitAnalyzer { /* private fields */ }
A Fancy object which counts gates and depth of a crate::circuit::Circuit.

Specifically, CircuitAnalyzer stores the number of inputs, ands, xors, negations, constants, multiplications, additions, subtractions, and multiplicative depth of the computation.

Implementations

Source

impl CircuitAnalyzer

pub fn new() -> CircuitAnalyzer

Create a new CircuitAnalyzer.

pub fn nands(&self) -> usize

The number of AND gates in the circuit.

pub fn ninputs(&self) -> usize

The number of input wires of the circuit.

pub fn nconstants(&self) -> usize

The number of constant wires of the circuit.

pub fn nxors(&self) -> usize

The number of XOR gates in the circuit.

pub fn eval<C: CircuitInputMapper<CircuitAnalyzer>>( &mut self, circuit: &C, ) -> Result<()>

Evaluate a circuit using CircuitAnalyzer.

The circuit needs to implement CircuitInputMapper as the circuit analysis is input-size-dependent.