CircuitAnalyzer

Struct CircuitAnalyzer 

pub struct CircuitAnalyzer { /* private fields */ }
A Fancy object which counts gates in a binary circuit.

Specifically, CircuitAnalyzer stores the number of inputs, ands, xors, negations, constants, multiplication, addition, subtraction, constant operations and multiplication depth of the circuits. This information is especially useful for pre-processing authenticated garbling circuits.

Implementations

Source

impl CircuitAnalyzer

pub fn new() -> CircuitAnalyzer

Create a new CircuitAnalyzer and sets all the gate counts to 0.

pub fn nands(&self) -> usize

Return the number of AND gates in the circuit

pub fn ninputs(&self) -> usize

Return the number of input wires of the circuit